aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorJohn Resig <jeresig@gmail.com>2007-03-24 03:12:12 +0000
committerJohn Resig <jeresig@gmail.com>2007-03-24 03:12:12 +0000
commit1b9f4d3d2e1bc2dfd7572da77159fa01f9ab5d6e (patch)
tree597c40a3682e6abbf47fd898f287a9cbc7255af5 /src
parentfde2867fce7b592096ae529ab5dcd0842e52f2ac (diff)
downloadjquery-1b9f4d3d2e1bc2dfd7572da77159fa01f9ab5d6e.tar.gz
jquery-1b9f4d3d2e1bc2dfd7572da77159fa01f9ab5d6e.zip
Simplified the easing options - we now provide "swing" and "linear" (defaulting to "swing"). This is in response to #928.
Diffstat (limited to 'src')
-rw-r--r--src/fx/fx.js20
1 files changed, 12 insertions, 8 deletions
diff --git a/src/fx/fx.js b/src/fx/fx.js
index 59cdceac5..0c57ef450 100644
--- a/src/fx/fx.js
+++ b/src/fx/fx.js
@@ -310,7 +310,7 @@ jQuery.fn.extend({
* @type jQuery
* @param Hash params A set of style attributes that you wish to animate, and to what end.
* @param String|Number speed (optional) A string representing one of the three predefined speeds ("slow", "normal", or "fast") or the number of milliseconds to run the animation (e.g. 1000).
* @param String easing (optional) The name of the easing effect that you want to use (Plugin Required).
* @param Function callback (optional) A function to be executed whenever the animation completes.
* @cat Effects
*/
@@ -364,7 +364,7 @@ jQuery.extend({
complete: fn || !fn && easing ||
jQuery.isFunction( speed ) && speed,
duration: speed,
- easing: fn && easing || easing && easing.constructor != Function && easing
+ easing: fn && easing || easing && easing.constructor != Function && easing || "swing"
};
opt.duration = (opt.duration && opt.duration.constructor == Number ?
@@ -382,7 +382,14 @@ jQuery.extend({
return opt;
},
- easing: {},
+ easing: {
+ linear: function( p, n, firstNum, diff ) {
+ return firstNum + diff * p;
+ },
+ swing: function( p, n, firstNum, diff ) {
+ return ((-Math.cos(p*Math.PI)/2) + 0.5) * diff + firstNum;
+ }
+ },
queue: {},
@@ -571,11 +578,8 @@ jQuery.extend({
// Figure out where in the animation we are and set the number
var p = n / options.duration;
- // If the easing function exists, then use it
- z.now = options.easing && jQuery.easing[options.easing] ?
- jQuery.easing[options.easing](p, n, firstNum, (lastNum-firstNum), options.duration) :
- // else use default linear easing
- ((-Math.cos(p*Math.PI)/2) + 0.5) * (lastNum-firstNum) + firstNum;
+ // Perform the easing function, defaults to swing
+ z.now = jQuery.easing[options.easing](p, n, firstNum, (lastNum-firstNum), options.duration);
// Perform the next step of the animation
z.a();
@@ -310,7 +310,7 @@ jQuery.fn.extend({
* @param Hash params A set of style attributes that you wish to animate, and to what end.
* @param String|Number speed (optional) A string representing one of the three predefined speeds ("slow", "normal", or "fast") or the number of milliseconds to run the animation (e.g. 1000).
- * @param String easing (optional) The name of the easing effect that you want to use (Plugin Required).
+ * @param String easing (optional) The name of the easing effect that you want to use (e.g. swing or linear). Defaults to "swing".
* @param Function callback (optional) A function to be executed whenever the animation completes.
* @cat Effects